/**
 * The purpose of this groovy script is to return all default libraries locations for Tomcat 5.x.
 *
 * EXPECTED INPUT:
 *		TOMCATHOME : the location of Tomcat installation
 *		EXOSRC     : the location of eXo source code main directory 
 *		VMInstall  : an instance of IVMInstall that represents the JDK to use for this configuration
 *
 * EXPECTED OUTPUT:
 *
 *		binLibraries    : all the jar files under the bin directory of Tomcat. These jar files are in 
 *						  a list of elements where each element in the list is a map. Each map might 
 *						  have one of the following keys:
 *						  	classes:  the path to a jar file or a folder that contains classes
 *							src:      the path to a zip file or a folder that contains the source code
 *							src-root: the path of the root source folder within a given src zip file.
 *									  only makes sense if the 'src' key has a value too.
 *
 *		serverlibraries : all the libraries that are used for the Tomcat server.
 *						  these libraries are returned in a list of elements just like binLibraries.
 * 
 *		commonLibraries : all the libraries that are considered common in terms of Tomcat. 
 *						  these libraries are returned in a list of elements just like binLibraries.
 * 
 *		sharedLibraries : all the libraries that are considered shared in terms of Tomcat. 
 *						  these libraries are returned in a list of elements just like binLibraries.
 *
 *		serverWebappsLibraries : all the libraries that are used by the webapps under the server part 
 *								 of Tomcat. These libraries are returned in a list of elements 
 *								 just like binLibraries.
 *
 *		defaultWebappsLibraries : all the libraries that are used by with the default webapps that are 
 *								  shipped with Tomcat. These libraries are returned in a list of elements 
 *								  just like binLibraries.
 *
 *		classpathLibraries	: all the libraries that need to be in classpath while starting Tomcat.
 *							  These libraries are returned in a list of elements just like binLibraries.
 *							  Note that the classpath libraries can be directories.
 *
 *		endorsedLibraries	: all the libraries that should be treated as endorsed while starting Tomcat.
 *							  These libraries are returned in a list of elements just like binLibraries.
 *							  Note that you still have to supply a vm argument for the endorsed directories.
 * 
 *		VMArguments 	: all the VM arguments required to start Tomcat. Note the you don't need to
 *						  include the classpath libraries in the arguments since they are supplied 
 *						  (see above). However, you still need to supply the endorsed directories as vm
 *						  arguments. All VM arguments are put in a list, and each element in the list is 
 *						  a map. Each map should have the following keys:
 *								key: 	the key of an argument entry. For example, '-Djava.io.tempdir'.
 *								value: 	the value of the argument.
 *								type: 	a String the represents the type of the VMArguments. Please see
 *									  	the comments in the VMArgumentType class.
 *
 */

if (TOMCATHOME == null) tomcatRoot = "";
else tomcatRoot=TOMCATHOME;

if (EXOSRC == null) exoSrc="";
else exoSrc=EXOSRC;

jdkRoot=VMInstall.getInstallLocation().getAbsolutePath();

///////////////////////////////////////// commonLibraries /////////////////////////////////////////////
commonLibraries=[];

// EXO-PLATFORM
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.commons-1.0.jar',
                     'src'    : exoSrc + '/exo-platform/commons/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.container-1.0.jar',
                     'src'    : exoSrc + '/exo-platform/container/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.backup.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/backup/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.backup.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/backup/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.cache.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/cache/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.cache.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/cache/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.chart.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/chart/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.chart.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/chart/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.common.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/common/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.common.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/common/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.database.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/database/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.database.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/database/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.grammar-analyser.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/grammar-analyser/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.grammar-analyser.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/grammar-analyser/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.id-generator.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/id-generator/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.id-generator.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/id-generator/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.indexing.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/indexing/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.indexing.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/indexing/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.ldap.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/ldap/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.ldap.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/ldap/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.monitor.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/monitor/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.monitor.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/monitor/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.organization.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/organization/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.organization.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/organization/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.remote.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/remote/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.remote.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/remote/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.resources.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/resources/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.resources.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/resources/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.security.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/security/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.security.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/security/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.templates.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/templates/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.templates.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/templates/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.xml-processing.api-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/xml-processing/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-platform.services.xml-processing.impl-2.0.jar',
                     'src'    : exoSrc + '/exo-platform/services/xml-processing/impl/src/java']);
// EXO-PORTAL
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-portal.jsf.core-components-1.1.jar',
                     'src'    : exoSrc + '/exo-portal/jsf/core-components/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-portal.jsf.exo-components-1.1.jar',
                     'src'    : exoSrc + '/exo-portal/jsf/exo-components/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-portal.portal.api-1.1.jar',
                     'src'    : exoSrc + '/exo-portal/portal/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-portal.portal.impl-1.1.jar',
                     'src'    : exoSrc + '/exo-portal/portal/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-portal.portlet-framework.commons-1.1.jar',
                     'src'    : exoSrc + '/exo-portal/portlet-framework/commons/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-portal.portlet-framework.jsf-1.1.jar',
                     'src'    : exoSrc + '/exo-portal/portlet-framework/jsf/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-portal.services.portal.api-1.1.jar',
                     'src'    : exoSrc + '/exo-portal/services/portal/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-portal.services.portal.impl-1.1.jar',
                     'src'    : exoSrc + '/exo-portal/services/portal/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-portal.services.portlet-container.api-1.1.jar',
                     'src'    : exoSrc + '/exo-portal/services/portlet-container/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-portal.services.portlet-container.impl-1.1.jar',
                     'src'    : exoSrc + '/exo-portal/services/portlet-container/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-portal.services.portlet-registry.api-1.1.jar',
                     'src'    : exoSrc + '/exo-portal/services/portlet-registry/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-portal.services.portlet-registry.impl-1.1.jar',
                     'src'    : exoSrc + '/exo-portal/services/portlet-registry/impl/src/java']);

// EXO-CMS
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-cms.jbpm-3.0.jar',
                     'src'    : exoSrc + '/exo-cms/exo-jbpm/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-cms.jsf.cms-components-1.0.jar',
                     'src'    : exoSrc + '/exo-cms/jsf/cms-components/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-cms.services.cms.api-1.0.jar',
                     'src'    : exoSrc + '/exo-cms/services/cms/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-cms.services.cms.impl-1.0.jar',
                     'src'    : exoSrc + '/exo-cms/services/cms/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-cms.services.jcr.api-1.0.jar',
                     'src'    : exoSrc + '/exo-cms/services/jcr/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-cms.services.jcr.impl-1.0.jar',
                     'src'    : exoSrc + '/exo-cms/services/jcr/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-cms.services.webdav.api-1.0.jar',
                     'src'    : exoSrc + '/exo-cms/services/webdav/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-cms.services.webdav.impl-1.0.jar',
                     'src'    : exoSrc + '/exo-cms/services/webdav/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-cms.services.workflow.api-1.0.jar',
                     'src'    : exoSrc + '/exo-cms/services/workflow/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-cms.services.workflow.impl-1.0.jar',
                     'src'    : exoSrc + '/exo-cms/services/workflow/impl/src/java']);
                     
// EXO-GROUPWARE
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-groupware.services.calendar.api-1.0.jar',
                     'src'    : exoSrc + '/exo-groupware/services/calendar/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-groupware.services.calendar.impl-1.0.jar',
                     'src'    : exoSrc + '/exo-groupware/services/calendar/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-groupware.services.forum.api-1.0.jar',
                     'src'    : exoSrc + '/exo-groupware/services/forum/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-groupware.services.forum.impl-1.0.jar',
                     'src'    : exoSrc + '/exo-groupware/services/forum/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-groupware.services.message.api-1.0.jar',
                     'src'    : exoSrc + '/exo-groupware/services/message/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-groupware.services.message.impl-1.0.jar',
                     'src'    : exoSrc + '/exo-groupware/services/message/impl/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-groupware.services.project-manager.api-1.0.jar',
                     'src'    : exoSrc + '/exo-groupware/services/project-manager/api/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-groupware.services.project-manager.impl-1.0.jar',
                     'src'    : exoSrc + '/exo-groupware/services/project-manager/impl/src/java']);

// EXO-TEST
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-test.webunit-framework-1.0.jar',
                     'src'    : exoSrc + '/exo-test/webunit-framework/src/java']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/exo-test.webunit-suites-1.0.jar',
                     'src'    : exoSrc + '/exo-test/webunit-suites/src/java']);


////////////////////////////////////// defaultWebappsLibraries ///////////////////////////////////////////
defaultWebappsLibraries=[];

// EXO-PORTAL
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/admin/WEB-INF/classes',
                             'src'    : exoSrc + '/exo-portal/portlets/admin/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/content/WEB-INF/classes',
                             'src'    : exoSrc + '/exo-portal/portlets/content/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/navigation/WEB-INF/classes',
                             'src'    : exoSrc + '/exo-portal/portlets/navigation/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/user/WEB-INF/classes',
                             'src'    : exoSrc + '/exo-portal/portlets/user/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/web/WEB-INF/classes',
                             'src'    : exoSrc + '/exo-portal/portlets/web/src/java']);

// EXO-CMS
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/cms-content/WEB-INF/classes',
                             'src'    : exoSrc + '/exo-cms/portlets/cms-content/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/workflow/WEB-INF/classes',
                             'src'    : exoSrc + '/exo-cms/portlets/workflow/src/java']);

// EXO-CALENDAR
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/calendar/WEB-INF/classes',
                             'src'    : exoSrc + '/exo-groupware/portlets/calendar/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/forum/WEB-INF/classes',
                             'src'    : exoSrc + '/exo-groupware/portlets/forum/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/message/WEB-INF/classes',
                             'src'    : exoSrc + '/exo-groupware/portlets/message/src/java']);
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/project-manager/WEB-INF/classes',
                             'src'    : exoSrc + '/exo-groupware/portlets/project-manager/src/java']);

/////////////////////////////////////////// VMArguments ///////////////////////////////////////////////
VMArguments=[];
VMArguments.add(['key':'-Dorg.apache.commons.logging.Log','type':'c=single,p=unknowm,s=assign','value':'org.apache.commons.logging.impl.SimpleLog']);
VMArguments.add(['key':'-Djava.security.auth.login.config','type':'c=multi,p=path,s=assign','value':tomcatRoot + '/conf/jaas.conf']);
VMArguments.add(['key':'-Xms64M','type':'c=0,p=unknowm,s=nospace']);
VMArguments.add(['key':'-Xmx128M','type':'c=0,p=unknowm,s=nospace']);
//VMArguments.add(['key':'-Xbootclasspath/p','type':'c=multi,p=path,s=attach','value':tomcatRoot + '/common/lib/aspectwerkz-2.0.jar;' + tomcatRoot +  '/common/lib/aspectwerkz-core-2.0.jar;' + tomcatRoot + '/common/lib/aspectwerkz-jdk5-2.0.jar;' + tomcatRoot + '/common/lib/trove-1.0.2.jar;' + tomcatRoot + '/common/lib/jrexx-1.1.1.jar;' + tomcatRoot + '/common/lib/dom4j-1.4.jar']);
