/**
 * The purpose of this groovy script is to return all default libraries locations for Tomcat 5.x.
 *
 * EXPECTED INPUT:
 *		TOMCATHOME : the location of Tomcat installation
 *		TOMCATSRC  : the location of Tomcat source 
 *		VMInstall  : an instance of IVMInstall that represents the JDK to use for this configuration
 *
 * EXPECTED OUTPUT:
 *
 *		mainTypeName	: the full class name to be used to start Tomcat.
 *
 *		startupArguments: the arguments used to startup Tomcat. 
 *
 *		shutdownArguments: the arguments used to stop Tomcat. 
 *
 *		suggestedWorkingDirectory: the default working directory 
 *
 *
 *		binLibraries    : all the jar files under the bin directory of Tomcat. These jar files are in 
 *						  a list of elements where each element in the list is a map. Each map might 
 *						  have one of the following keys:
 *						  	classes:  the path to a jar file or a folder that contains classes
 *							src:      the path to a zip file or a folder that contains the source code
 *							src-root: the path of the root source folder within a given src zip file.
 *									  only makes sense if the 'src' key has a value too.
 *
 *		serverlibraries : all the libraries that are used for the Tomcat server.
 *						  these libraries are returned in a list of elements just like binLibraries.
 * 
 *		commonLibraries : all the libraries that are considered common in terms of Tomcat. 
 *						  these libraries are returned in a list of elements just like binLibraries.
 * 
 *		sharedLibraries : all the libraries that are considered shared in terms of Tomcat. 
 *						  these libraries are returned in a list of elements just like binLibraries.
 *
 *		serverWebappsLibraries : all the libraries that are used by the webapps under the server part 
 *								 of Tomcat. These libraries are returned in a list of elements 
 *								 just like binLibraries.
 *
 *		defaultWebappsLibraries : all the libraries that are used by with the default webapps that are 
 *								  shipped with Tomcat. These libraries are returned in a list of elements 
 *								  just like binLibraries.
 *
 *		classpathLibraries	: all the libraries that need to be in classpath while starting Tomcat.
 *							  These libraries are returned in a list of elements just like binLibraries.
 *							  Note that the classpath libraries can be directories.
 *
 *		endorsedLibraries	: all the libraries that should be treated as endorsed while starting Tomcat.
 *							  These libraries are returned in a list of elements just like binLibraries.
 *							  Note that you still have to supply a vm argument for the endorsed directories.
 * 
 *		VMArguments 	: all the VM arguments required to start Tomcat. Note the you don't need to
 *						  include the classpath libraries in the arguments since they are supplied 
 *						  (see above). However, you still need to supply the endorsed directories as vm
 *						  arguments. All VM arguments are put in a list, and each element in the list is 
 *						  a map. Each map should have the following keys:
 *								key: 	the key of an argument entry. For example, '-Djava.io.tempdir'.
 *								value: 	the value of the argument.
 *								type: 	a String the represents the type of the VMArguments. Please see
 *									  	the comments in the VMArgumentType class.
 *
 */

if (TOMCATHOME == null) tomcatRoot = "";
else tomcatRoot=TOMCATHOME;

if (TOMCATSRC == null) tomcatSrc="";
else tomcatSrc=TOMCATSRC;

jdkRoot=VMInstall.getInstallLocation().getAbsolutePath();

/////////////////////////////////////////// mainTypeName ///////////////////////////////////////////////
mainTypeName='org.apache.catalina.startup.Bootstrap';

//////////////////////////////////////// startupArguments //////////////////////////////////////////////
startupArguments=[];
startupArguments.add('start');

//////////////////////////////////////// shutdownArguments //////////////////////////////////////////////
shutdownArguments=[];
shutdownArguments.add('stop');

//////////////////////////////////// suggestedWorkingDirectory //////////////////////////////////////////
suggestedWorkingDirectory=tomcatRoot+'/bin';

/////////////////////////////////////////// binLibraries ///////////////////////////////////////////////
binLibraries=[];
binLibraries.add(['classes': tomcatRoot + '/bin/bootstrap.jar', 
				  'src'	   : tomcatSrc + '/jakarta-tomcat-catalina/catalina/src/share']);
binLibraries.add(['classes': tomcatRoot + '/bin/commons-daemon.jar']);
binLibraries.add(['classes': tomcatRoot + '/bin/commons-launcher.jar']); 
binLibraries.add(['classes': tomcatRoot + '/bin/commons-logging-api.jar']); 
binLibraries.add(['classes': tomcatRoot + '/bin/jmx.jar']); 

///////////////////////////////////////// serverLibraries /////////////////////////////////////////////
serverLibraries=[];
serverLibraries.add(['classes': tomcatRoot + '/server/classes']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/catalina.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-catalina/catalina/src/share']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/catalina-ant.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-catalina/catalina/src/share']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/catalina-cluster.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-catalina/modules/cluster/src/share']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/catalina-optional.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-catalina/catalina/src/share']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/commons-beanutils.jar']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/commons-digester.jar']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/commons-fileupload-1.0.jar']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/commons-modeler.jar']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/jakarta-regexp-1.3.jar']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/jkconfig.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-connectors/jk/java']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/servlets-common.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-catalina/catalina/src/share']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/servlets-default.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-catalina/catalina/src/share']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/servlets-invoker.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-catalina/catalina/src/share']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/servlets-webdav.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-catalina/catalina/src/share']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/tomcat-coyote.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-connectors/coyote/src/java']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/tomcat-http11.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-connectors/http11/src/java']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/tomcat-jk2.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-connectors/jk/java']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/tomcat-jni.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-connectors/jk/java']);
serverLibraries.add(['classes': tomcatRoot + '/server/lib/tomcat-util.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-connectors/util/java']);

///////////////////////////////////////// commonLibraries /////////////////////////////////////////////
commonLibraries=[];
commonLibraries.add(['classes': tomcatRoot + '/common/classes']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/ant-launcher.jar']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/ant.jar']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/commons-collections-2.1.1.jar']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/commons-dbcp-1.2.1.jar']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/commons-el.jar']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/commons-pool-1.2.jar']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/jasper-compiler.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-jasper/jasper2/src/share']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/jasper-runtime.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-jasper/jasper2/src/share']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/jsp-api.jar',
					 'src'	  : tomcatSrc + '/jakarta-servletapi-5/jsr152/src/share']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/naming-common.jar']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/naming-factory.jar']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/naming-java.jar']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/naming-resources.jar']);
commonLibraries.add(['classes': tomcatRoot + '/common/lib/servlet-api.jar',
					 'src'	  : tomcatSrc + '/jakarta-servletapi-5/jsr154/src/share']);

//////////////////////////////////////// sharedLibraries /////////////////////////////////////////////
sharedLibraries=[];
sharedLibraries.add(['classes': tomcatRoot + '/shared/classes']);

////////////////////////////////////// serverWebappsLibraries ///////////////////////////////////////////
serverWebappsLibraries=[];
serverWebappsLibraries.add(['classes': tomcatRoot+ '/server/webapps/admin/WEB-INF/lib/catalina-admin.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-catalina/webapps/admin/WEB-INF/classes']);
serverWebappsLibraries.add(['classes': tomcatRoot+ '/server/webapps/admin/WEB-INF/lib/struts.jar']);

serverWebappsLibraries.add(['classes': tomcatRoot+ '/server/webapps/manager/WEB-INF/lib/catalina-manager.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-catalina/webapps/manager/WEB-INF/classes']);

////////////////////////////////////// defaultWebappsLibraries ///////////////////////////////////////////
defaultWebappsLibraries=[];
defaultWebappsLibraries.add(['classes': tomcatRoot + '/webapps/balancer/WEB-INF/lib/catalina-balancer.jar',
					 'src'	  : tomcatSrc + '/jakarta-tomcat-catalina/webapps/balancer/WEB-INF/classes']);

///////////////////////////////////////// classpathLibraries /////////////////////////////////////////////
classpathLibraries=[];
classpathLibraries.add(['classes': tomcatRoot + '/bin/bootstrap.jar', 
						'src': tomcatSrc + '/jakarta-tomcat-catalina/catalina/src/share']);

// we have a special case for MAC OS, the tools.jar is not required
osName = System.getProperty("os.name");
if ((osName != null) && (!osName.startsWith("Mac OS")))
{						
	classpathLibraries.add(['classes': jdkRoot+ '/lib/tools.jar']);
}

///////////////////////////////////////// endorsedLibraries /////////////////////////////////////////////
endorsedLibraries=[];
endorsedLibraries.add(['classes': tomcatRoot + '/common/endorsed/xercesImpl.jar']);
endorsedLibraries.add(['classes': tomcatRoot + '/common/endorsed/xml-apis.jar']);

/////////////////////////////////////////// VMArguments ///////////////////////////////////////////////
VMArguments=[];
VMArguments.add(['key':'-Dcatalina.base','type':'c=single,p=path,s=assign','value':tomcatRoot]);
VMArguments.add(['key':'-Dcatalina.home','type':'c=single,p=path,s=assign','value':tomcatRoot]);
VMArguments.add(['key':'-Dcatalina.tempdir','type':'c=single,p=path,s=assign','value':tomcatRoot+'/temp']);
VMArguments.add(['key':'-Djava.endorsed.dirs','type':'c=multi,p=path,s=assign','value':tomcatRoot+ '/common/endorsed']);
VMArguments.add(['key':'-Djava.library.path','type':'c=multi,p=path,s=assign','value':jdkRoot+ '/bin']);
VMArguments.add(['key':'-Djava.library.path','type':'c=multi,p=path,s=assign','value':tomcatRoot+ '/bin']);
VMArguments.add(['key':'-Djava.io.tmpdir','type':'c=multi,p=path,s=assign','value':tomcatRoot+ '/temp']);
VMArguments.add(['key':'-Dsun.io.useCanonCaches','type':'c=single,p=unknown,s=assign','value':'false']);
